#
# jc2kisoNB.awk : A awk script to convert magnitudes in Johnson Cousins system 
#               into those in KISO Observatory Narrow Band system.  
#
# USAGE: awk -f jc2kisoNB.awk [Input File name] > [Output File name] 
#
# Input File Format 
# --------------------------------------------------
# #INPUT = JohnsonCOusins
# #OUTPUT = KisoNB
# #  name    UJ    BJ    VJ    Rc    Ic
# SAxx-yyy 10.00 10.50 10.75 11.00 11.25
#     :      :     :     :     :     :
#     :      :     :     :     :     :
#     :      :     :     :     :     :
# --------------------------------------------------  
#
BEGIN{ i=0;
       fU0=4.28*(10**(-9)); 
       fB0=6.19*(10**(-9));
       fV0=3.60*(10**(-9));
       fR0=2.15*(10**(-9));
       fI0=1.11*(10**(-9));
       Fconv = 3.33564*(10**(-19));
     }

     {
       if( substr($1,1,1)!="#" )
         {
           name[i] = $1;
           UJ[i]   = $2;
           BJ[i]   = $3;
           VJ[i]   = $4;
           Rc[i]   = $5;
           Ic[i]   = $6;
           ++i;
           i_max   = i;
         }
     }

END{ 
     print " Name AB(N487) AB(N499) AB(N519) AB(Ha6417) AB(Ha6577) AB(Ha6737)";

     for(i=0;i<i_max;++i)
       {
         fU      = fU0*(10**(-0.4*UJ[i]));
         fB      = fB0*(10**(-0.4*BJ[i])); 
         fV      = fV0*(10**(-0.4*VJ[i]));
         fR      = fR0*(10**(-0.4*Rc[i]));
         fI      = fI0*(10**(-0.4*Ic[i]));
         fN487   = Fconv*(50.8515*fB+35.1485*fV)/86*4879*4879; 
         fN499   = Fconv*(55.5440*fB+58.4560*fV)/114*4993*4993; 
         fN519   = Fconv*(36.1268*fB+85.8732*fV)/122*5179*5179;
         fHa6417 = Fconv*(11.1242*fV+67.8758*fR)/79*6417*6417;
         fHa6577 = Fconv*( 0.5028*fV+81.6481*fR + 0.8492 * fI)/83*6577*6577;
         fHa6737 = Fconv*(73.4426*fR+ 9.5574*fI)/83*6737*6737;
         AB487   = -2.5 * 0.43429 * log(fN487) - 48.60;
         AB499   = -2.5 * 0.43429 * log(fN499) - 48.60; 
         AB519   = -2.5 * 0.43429 * log(fN519) - 48.60;
         AB6417  = -2.5 * 0.43429 * log(fHa6417) - 48.60;
         AB6577  = -2.5 * 0.43429 * log(fHa6577) - 48.60;
         AB6737  = -2.5 * 0.43429 * log(fHa6737) - 48.60;

         #print name[i]"  "fN487"  "fN499"  "fN519"  "fHa6417"  "fHa6577"  "fHa6737; 
         #print name[i]"  "log(fN487)"  "log(fN499)"  "log(fN519)"  "log(fHa6417)"  "log(fHa6577)"  "log(fHa6737); 
         print name[i]"  "AB487"  "AB499"  "AB519"  "AB6417"  "AB6577"  "AB6737; 
 
       }
 
     #print i_max;
     }
