#
# sdss2jc.awk : A awk script to convert magnitudes in SDSS ugriz system 
#               into those in Johnson Cousins system.  
#
# USAGE: awk -f sdss2jc.awk [Input File name] > [Output File name] 
#
# Input File Format 
# --------------------------------------------------
# #INPUT = SDSS
# #OUTPUT = JohnsonCousins
# #     name            u     g     r     i     z
# Jxxxxxx.xx+yyyyyy.y 10.00 10.50 10.75 11.00 11.25
#   :     :     :     :     :
#   :     :     :     :     :
#   :     :     :     :     :
# --------------------------------------------------  
#
BEGIN{
       i=0; 
     }

     {
       if( substr($1,1,1)!="#" )
         {
           name[i]   = $1;
           u_sdss[i] = $2;
           g_sdss[i] = $3;
           r_sdss[i] = $4;
           i_sdss[i] = $5;
           z_sdss[i] = $6;
           ++i;
           i_max     = i;
         }
     }

END{ 
     for(i=0;i<i_max;++i)
       {
         BJ[i] = g_sdss[i] + 0.47 * (g_sdss[i] - r_sdss[i]) + 0.17;
         VJ[i] = g_sdss[i] - 0.55 * (g_sdss[i] - r_sdss[i]) - 0.03; 
         UJ[i] = BJ[i] + 0.75 * (u_sdss[i] - g_sdss[i]) - 0.83;
         Rc[i] = VJ[i] - 0.59 * (g_sdss[i] - r_sdss[i]) - 0.11;
         if((r_sdss[i]-i_sdss[i])<0.95)
           {
             Ic[i] = Rc[i] - 1.00 * (r_sdss[i] - i_sdss[i]) - 0.21;
           }
         if((r_sdss[i]-i_sdss[i])>=0.95)
           {
             Ic[i] = Rc[i] - 0.70 * (r_sdss[i] - i_sdss[i]) - 0.49;
           }
       }
 
     #print i_max;

     for(i=0;i<i_max;++i)
       {
         print "Name= "name[i]" UJ= "UJ[i]" BJ= "BJ[i]" VJ="VJ[i]" Rc= "Rc[i]" Ic= "Ic[i];
       }
     
     }
